@@ -9,5 +9,7 @@ def require_permission(perm_func):
             if not perm_func(*args, **kwargs):
                 # TODO : Handle errors
                 print("Not allowed")
+                return
+            func(*args, **kwargs)
         return wrapper
     return decored
